@@ -1,6 +1,7 @@
 package filter
 
 import (
+	"errors"
 	"fmt"
 	"os"
 	"strings"
@@ -9,6 +10,8 @@ import (
 	"github.com/charmbracelet/bubbles/textinput"
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
+	"github.com/sahilm/fuzzy"
+
 	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/internal/files"
 	"github.com/charmbracelet/gum/internal/stdin"
@@ -30,20 +33,35 @@ func (o Options) Run() error {
 
 	var choices []string
 	if input, _ := stdin.Read(); input != "" {
-		choices = strings.Split(strings.TrimSpace(input), "\n")
+		input = strings.TrimSpace(input)
+		if input != "" {
+			choices = strings.Split(input, "\n")
+		}
 	} else {
 		choices = files.List()
 	}
 
+	if len(choices) == 0 {
+		return errors.New("no options provided, see `gum filter --help`")
+	}
+
 	options := []tea.ProgramOption{tea.WithOutput(os.Stderr)}
 	if o.Height == 0 {
 		options = append(options, tea.WithAltScreen())
 	}
 
+	var matches []fuzzy.Match
+	if o.Value != "" {
+		i.SetValue(o.Value)
+		matches = fuzzy.Find(o.Value, choices)
+	} else {
+		matches = matchAll(choices)
+	}
+
 	p := tea.NewProgram(model{
 		choices:        choices,
 		indicator:      o.Indicator,
-		matches:        matchAll(choices),
+		matches:        matches,
 		textinput:      i,
 		viewport:       &v,
 		indicatorStyle: o.IndicatorStyle.ToLipgloss(),
@@ -53,6 +71,9 @@ func (o Options) Run() error {
 	}, options...)
 
 	tm, err := p.StartReturningModel()
+	if err != nil {
+		return fmt.Errorf("unable to run filter: %w", err)
+	}
 	m := tm.(model)
 
 	if m.aborted {
@@ -62,10 +83,11 @@ func (o Options) Run() error {
 		fmt.Println(m.matches[m.selected].Str)
 	}
 
-	return err
+	return nil
 }
 
 // BeforeReset hook. Used to unclutter style flags.
 func (o Options) BeforeReset(ctx *kong.Context) error {
-	return style.HideFlags(ctx)
+	style.HideFlags(ctx)
+	return nil
 }
