@@ -7,8 +7,7 @@
 //
 // I.e. let's pick from a list of gum flavors:
 //
-//   $ cat flavors.text | gum filter
-//
+// $ cat flavors.text | gum filter
 package filter
 
 import (
@@ -136,9 +135,9 @@ func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 }
 
 func matchAll(options []string) []fuzzy.Match {
-	var matches []fuzzy.Match
-	for _, option := range options {
-		matches = append(matches, fuzzy.Match{Str: option})
+	var matches = make([]fuzzy.Match, len(options))
+	for i, option := range options {
+		matches[i] = fuzzy.Match{Str: option}
 	}
 	return matches
 }
